@@ -1,7 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * Copyright (C) 2006, Mr Jamie McCracken (jamiemcc@gnome.org)
- * Copyright (C) 2008, Nokia
+ * Copyright (C) 2008, Nokia (urho.konttori@nokia.com)
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -19,9 +18,12 @@
  * Boston, MA  02110-1301, USA.
  */
 
+#include "config.h"
+
 #include <gio/gio.h>
 
 #include "tracker-dbus.h"
+#include "tracker-log.h"
 
 struct TrackerDBusRequestHandler {
 	TrackerDBusRequestFunc new;
@@ -334,6 +336,24 @@ tracker_dbus_request_failed (gint	   request_id,
 	g_free (str);
 }
 
+void
+tracker_dbus_request_info (gint	        request_id,
+			   const gchar *format,
+			   ...)
+{
+	gchar	*str;
+	va_list  args;
+
+	va_start (args, format);
+	str = g_strdup_vprintf (format, args);
+	va_end (args);
+
+	tracker_info ("---- [%d] %s",
+		      request_id,
+		      str);
+	g_free (str);
+}
+
 void
 tracker_dbus_request_comment (gint	   request_id,
 			      const gchar *format,
