@@ -54,7 +54,16 @@ extern void tracker_marshal_VOID__STRING_DOUBLE (GClosure     *closure,
                                                  gpointer      invocation_hint,
                                                  gpointer      marshal_data);
 
-/* BOOL:OBJECT,OBJECT (tracker-marshal.list:7) */
+/* BOOL:OBJECT,OBJECT,OBJECT (tracker-marshal.list:7) */
+extern void tracker_marshal_BOOLEAN__OBJECT_OBJECT_OBJECT (GClosure     *closure,
+                                                           GValue       *return_value,
+                                                           guint         n_param_values,
+                                                           const GValue *param_values,
+                                                           gpointer      invocation_hint,
+                                                           gpointer      marshal_data);
+#define tracker_marshal_BOOL__OBJECT_OBJECT_OBJECT	tracker_marshal_BOOLEAN__OBJECT_OBJECT_OBJECT
+
+/* BOOL:OBJECT,OBJECT (tracker-marshal.list:8) */
 extern void tracker_marshal_BOOLEAN__OBJECT_OBJECT (GClosure     *closure,
                                                     GValue       *return_value,
                                                     guint         n_param_values,
@@ -63,7 +72,7 @@ extern void tracker_marshal_BOOLEAN__OBJECT_OBJECT (GClosure     *closure,
                                                     gpointer      marshal_data);
 #define tracker_marshal_BOOL__OBJECT_OBJECT	tracker_marshal_BOOLEAN__OBJECT_OBJECT
 
-/* BOOL:OBJECT,POINTER (tracker-marshal.list:8) */
+/* BOOL:OBJECT,POINTER (tracker-marshal.list:9) */
 extern void tracker_marshal_BOOLEAN__OBJECT_POINTER (GClosure     *closure,
                                                      GValue       *return_value,
                                                      guint         n_param_values,
@@ -72,7 +81,7 @@ extern void tracker_marshal_BOOLEAN__OBJECT_POINTER (GClosure     *closure,
                                                      gpointer      marshal_data);
 #define tracker_marshal_BOOL__OBJECT_POINTER	tracker_marshal_BOOLEAN__OBJECT_POINTER
 
-/* BOOL:OBJECT (tracker-marshal.list:9) */
+/* BOOL:OBJECT (tracker-marshal.list:10) */
 extern void tracker_marshal_BOOLEAN__OBJECT (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
