@@ -28,15 +28,16 @@
 
 #include <libtracker-common/tracker-dbus.h>
 #include <libtracker-common/tracker-sparql-builder.h>
+#include <libtracker-common/tracker-log.h>
 
 #include "tracker-dbus.h"
 #include "tracker-extract.h"
 #include "tracker-main.h"
 #include "tracker-marshal.h"
 
-#ifdef HAVE_STREAMANALYZER
+#ifdef HAVE_LIBSTREAMANALYZER
 #include "tracker-topanalyzer.h"
-#endif
+#endif /* HAVE_STREAMANALYZER */
 
 #define MAX_EXTRACT_TIME 10
 
@@ -47,6 +48,8 @@ extern gboolean debug;
 typedef struct {
 	GArray *specific_extractors;
 	GArray *generic_extractors;
+	gboolean disable_shutdown;
+	gboolean force_internal_extractors;
 } TrackerExtractPrivate;
 
 typedef struct { 
@@ -92,9 +95,9 @@ tracker_extract_class_init (TrackerExtractClass *klass)
 static void
 tracker_extract_init (TrackerExtract *object)
 {
-#ifdef HAVE_STREAMANALYZER
+#ifdef HAVE_LIBSTREAMANALYZER
 	tracker_topanalyzer_init ();
-#endif
+#endif /* HAVE_STREAMANALYZER */
 }
 
 static void
@@ -104,9 +107,9 @@ tracker_extract_finalize (GObject *object)
 
 	priv = TRACKER_EXTRACT_GET_PRIVATE (object);
 
-#ifdef HAVE_STREAMANALYZER
+#ifdef HAVE_LIBSTREAMANALYZER
 	tracker_topanalyzer_shutdown ();
-#endif
+#endif /* HAVE_STREAMANALYZER */
 
 	g_array_free (priv->specific_extractors, TRUE);
 	g_array_free (priv->generic_extractors, TRUE);
@@ -115,7 +118,8 @@ tracker_extract_finalize (GObject *object)
 }
 
 TrackerExtract *
-tracker_extract_new (void)
+tracker_extract_new (gboolean disable_shutdown,
+		     gboolean force_internal_extractors)
 {
 	TrackerExtract *object;
 	TrackerExtractPrivate *priv;
@@ -139,6 +143,16 @@ tracker_extract_new (void)
 		return NULL;
 	}
 
+#ifdef HAVE_LIBSTREAMANALYZER
+	if (!force_internal_extractors) {
+		g_message ("Adding extractor for libstreamanalyzer");
+		g_message ("  Generic  match for ALL (tried first before our module)");
+		g_message ("  Specific match for NONE (fallback to our modules)");
+	} else {
+		g_message ("Not using libstreamanalyzer");
+		g_message ("  It is available but disabled by command line");
+	}
+#endif /* HAVE_STREAMANALYZER */
 	specific_extractors = g_array_new (FALSE,
 					   TRUE,
 					   sizeof (ModuleData));
@@ -202,6 +216,9 @@ tracker_extract_new (void)
 
 	priv = TRACKER_EXTRACT_GET_PRIVATE (object);
 
+	priv->disable_shutdown = disable_shutdown;
+	priv->force_internal_extractors = force_internal_extractors;
+
 	priv->specific_extractors = specific_extractors;
 	priv->generic_extractors = generic_extractors;
 
@@ -214,27 +231,44 @@ get_file_metadata (TrackerExtract *extract,
 		   const gchar    *uri,
 		   const gchar    *mime)
 {
+	TrackerExtractPrivate *priv;
 	TrackerSparqlBuilder *statements;
 	gchar *mime_used = NULL;
 	gchar *content_type = NULL;
 
+	priv = TRACKER_EXTRACT_GET_PRIVATE (extract);
+
 	/* Create hash table to send back */
 	statements = tracker_sparql_builder_new_update ();
 
 	tracker_sparql_builder_insert_open (statements);
 
-#ifdef HAVE_STREAMANALYZER
-	tracker_topanalyzer_extract (uri, statements, &content_type);
-
-	if ((!mime || mime[0]=='\0') && content_type) {
-		mime = content_type;
+#ifdef HAVE_LIBSTREAMANALYZER
+	if (!priv->force_internal_extractors) {
+		tracker_dbus_request_comment (request_id,
+					      "  Extracting with libstreamanalyzer...");
+		
+		tracker_topanalyzer_extract (uri, statements, &content_type);
+		
+		if (tracker_sparql_builder_get_length (statements) > 0) {
+			g_free (content_type);
+			tracker_sparql_builder_insert_close (statements);
+			return statements;
+		}
+	} else {
+		tracker_dbus_request_comment (request_id,
+					      "  Extracting with internal extractors ONLY...");
 	}
-#endif
+#endif /* HAVE_LIBSTREAMANALYZER */
 
 	if (mime && *mime) {
 		/* We know the mime */
 		mime_used = g_strdup (mime);
 		g_strstrip (mime_used);
+	} else if (content_type && *content_type) {
+		/* We know the mime from LSA */
+		mime_used = content_type;
+		g_strstrip (mime_used);
 	} else {
 		GFile *file;
 		GFileInfo *info;
@@ -244,7 +278,6 @@ get_file_metadata (TrackerExtract *extract,
 		if (!file) {
 			g_warning ("Could not create GFile for uri:'%s'",
 				   uri);
-			g_free (content_type);
 			g_object_unref (statements);
 			return NULL;
 		}
@@ -266,7 +299,6 @@ get_file_metadata (TrackerExtract *extract,
 			}
 
 			g_object_unref (file);
-			g_free (content_type);
 			g_object_unref (statements);
 			return NULL;
 		}
@@ -286,11 +318,8 @@ get_file_metadata (TrackerExtract *extract,
 	 * data we need from the extractors.
 	 */
 	if (mime_used) {
-		TrackerExtractPrivate *priv;
 		guint i;
 
-		priv = TRACKER_EXTRACT_GET_PRIVATE (extract);
-
 		for (i = 0; i < priv->specific_extractors->len; i++) {
 			const TrackerExtractData *edata;
 			ModuleData mdata;
@@ -319,7 +348,6 @@ get_file_metadata (TrackerExtract *extract,
 				tracker_sparql_builder_insert_close (statements);
 
 				g_free (mime_used);
-				g_free (content_type);
 
 				return statements;
 			}
@@ -353,7 +381,6 @@ get_file_metadata (TrackerExtract *extract,
 				tracker_sparql_builder_insert_close (statements);
 
 				g_free (mime_used);
-				g_free (content_type);
 
 				return statements;
 			}
@@ -370,8 +397,6 @@ get_file_metadata (TrackerExtract *extract,
 
 	tracker_sparql_builder_insert_close (statements);
 
-	g_free (content_type);
-
 	return statements;
 }
 
@@ -397,8 +422,8 @@ tracker_extract_get_metadata_by_cmdline (TrackerExtract *object,
 	statements = get_file_metadata (object, request_id, uri, mime);
 
 	if (statements) {
-		tracker_dbus_request_debug (request_id, "%s",
-		                            tracker_sparql_builder_get_result (statements));
+		tracker_dbus_request_info (request_id, "%s",
+					   tracker_sparql_builder_get_result (statements));
 		g_object_unref (statements);
 	}
 
@@ -434,7 +459,8 @@ tracker_extract_get_metadata (TrackerExtract	     *object,
 			      DBusGMethodInvocation  *context,
 			      GError		    **error)
 {
-	guint       request_id;
+	guint request_id;
+	TrackerExtractPrivate *priv;
 	TrackerSparqlBuilder *sparql = NULL;
 
 	request_id = tracker_dbus_get_next_request_id ();
@@ -449,9 +475,11 @@ tracker_extract_get_metadata (TrackerExtract	     *object,
 
 	tracker_dbus_request_debug (request_id,
 				    "  Resetting shutdown timeout");
+
+	priv = TRACKER_EXTRACT_GET_PRIVATE (object);
 	
 	tracker_main_quit_timeout_reset ();
-	if (!debug) {
+	if (!priv->disable_shutdown) {
 		alarm (MAX_EXTRACT_TIME);
 	}
 
@@ -459,6 +487,7 @@ tracker_extract_get_metadata (TrackerExtract	     *object,
 
 	if (sparql) {
 		if (tracker_sparql_builder_get_length (sparql) > 0) {
+			/* tracker_info ("%s", tracker_sparql_builder_get_result (sparql)); */
 			dbus_g_method_return (context, tracker_sparql_builder_get_result (sparql));
 		} else {
 			dbus_g_method_return (context, "");
@@ -477,7 +506,7 @@ tracker_extract_get_metadata (TrackerExtract	     *object,
 		g_error_free (actual_error);
 	}
 
-	if (!debug) {
+	if (!priv->disable_shutdown) {
 		/* Unset alarm so the extractor doesn't die when it's idle */
 		alarm (0);
 	}
