@@ -50,7 +50,8 @@ struct TrackerExtractClass {
 };
 
 GType           tracker_extract_get_type                (void);
-TrackerExtract *tracker_extract_new                     (gboolean                disable_shutdown);
+TrackerExtract *tracker_extract_new                     (gboolean                disable_shutdown,
+							 gboolean                force_internal_extractors);
 void            tracker_extract_get_pid                 (TrackerExtract         *object,
 							 DBusGMethodInvocation  *context,
 							 GError                **error);
