@@ -272,7 +272,7 @@ void tracker_metadata_tile_LoadUri (TrackerMetadataTile* self, const GtkTreePath
 #line 183 "tracker-metadata-tile.gs"
 	gtk_button_set_label ((GtkButton*) self->name_link, filepath);
 #line 275 "tracker-metadata-tile.c"
-	query = g_strdup_printf ("SELECT ?mimetype WHERE {<%s> nie:mimeType ?mimeType.}", uri);
+	query = g_strdup_printf ("SELECT ?mimetype WHERE {<%s> nie:mimeType ?mimetype.}", uri);
 #line 188 "tracker-metadata-tile.gs"
 	if (self->priv->_Query != NULL) {
 #line 279 "tracker-metadata-tile.c"
